@@ -1,16 +1,19 @@
-import ast
 from typing import Any, List
 
+
 class ReturnException(Exception):
     def __init__(self, value: Any) -> None:
         self.value: Any = value
 
+
 class BreakException(Exception):
     pass
 
+
 class ContinueException(Exception):
     pass
 
+
 class BaseExceptionGroup(Exception):
     def __init__(self, message: str, exceptions: List[Exception]):
         super().__init__(message)
@@ -20,6 +23,7 @@ class BaseExceptionGroup(Exception):
     def __str__(self):
         return f"{self.message}: {', '.join(str(e) for e in self.exceptions)}"
 
+
 class WrappedException(Exception):
     def __init__(self, message: str, original_exception: Exception, lineno: int, col: int, context_line: str):
         super().__init__(message)
@@ -31,10 +35,4 @@ class WrappedException(Exception):
 
     def __str__(self):
         exc_type = type(self.original_exception).__name__
-        return f"{exc_type} at line {self.lineno}, col {self.col}:\n{self.context_line}\nDescription: {self.message}"
-
-def has_await(node: ast.AST) -> bool:
-    for child in ast.walk(node):
-        if isinstance(child, ast.Await):
-            return True
-    return False
\ No newline at end of file
+        return f"{exc_type} at line {self.lineno}, col {self.col}:\n{self.context_line}\nDescription: {self.message}"
\ No newline at end of file
